package com.master.playit.helper;

import android.content.ContentValues;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

import java.sql.Date;
import java.util.ArrayList;

public class XmlGeneratorHelper {

    public static void generateUserNode(Document doc, String nickname, int id) {
        Node userElt = doc.createElement("user");
        doc.appendChild(userElt);

        Node idElt = doc.createElement("id");
        idElt.setTextContent(String.valueOf(id));
        userElt.appendChild(idElt);

        Node nameElt = doc.createElement(General.GAME_PREFERENCES_NICKNAME);
        nameElt.setTextContent(nickname);
        userElt.appendChild(nameElt);
    }

    public static void generatePuzzleNode(Document doc, ContentValues puzzle, ArrayList<String> coAuthors, String nickname) {
        Node puzzleElt = doc.createElement("puzzle");
        doc.appendChild(puzzleElt);

        Node subjectElt = doc.createElement("name");
        subjectElt.setTextContent(puzzle.getAsString(General.PUZZLE_NAME));
        puzzleElt.appendChild(subjectElt);

        Node contentElt = doc.createElement("category");
        contentElt.setTextContent(puzzle.getAsString(General.PUZZLE_CATEGORY));
        puzzleElt.appendChild(contentElt);

        Node ratingElt = doc.createElement("rating");
        ratingElt.setTextContent("0");
        puzzleElt.appendChild(ratingElt);

        Node timesPlayedElt = doc.createElement("timesplayed");
        timesPlayedElt.setTextContent("0");
        puzzleElt.appendChild(timesPlayedElt);

        Node authorElt = doc.createElement(General.XML_TAG_AUTHOR);
        authorElt.setTextContent(nickname);
        puzzleElt.appendChild(authorElt);

        if (coAuthors.size() > 0) {
            Node coauthorsElt = doc.createElement(General.XML_TAG_COAUTHORS);
            puzzleElt.appendChild(coauthorsElt);

            for (String author : coAuthors) {
                Node coauthorElt = doc.createElement(General.XML_TAG_COAUTHOR);
                coauthorElt.setTextContent(author);
                coauthorsElt.appendChild(coauthorElt);
            }
        }
    }

    public static void generateFriendNode(Document doc, String friend) {
        Node friendElt = doc.createElement("friend");
        doc.appendChild(friendElt);

        Node field;
        if (friend.contains("@")) {
            field = doc.createElement(General.GAME_PREFERENCES_EMAIL);
        } else {
            field = doc.createElement(General.GAME_PREFERENCES_NICKNAME);
        }
        field.setTextContent(friend);
        friendElt.appendChild(field);
    }

    public static void generateScoreNode(Document doc, int puzzleId, String nickname, int score, String time) {
        Node scoreElt = doc.createElement("score");
        doc.appendChild(scoreElt);

        Node idElt = doc.createElement("puzzleId");
        idElt.setTextContent(String.valueOf(puzzleId));
        scoreElt.appendChild(idElt);

        Node nameElt = doc.createElement(General.GAME_PREFERENCES_NICKNAME);
        nameElt.setTextContent(nickname);
        scoreElt.appendChild(nameElt);

        Node valueElt = doc.createElement("value");
        valueElt.setTextContent(String.valueOf(score));
        scoreElt.appendChild(valueElt);

        Node timeELt = doc.createElement("totalTime");
        timeELt.setTextContent(time);
        scoreElt.appendChild(timeELt);
    }

    public static void generateRequestNode(Document doc, String id, String userId, String receiverId, String puzzleId,
                                           String name, String type, int score) {
        Node requestElt = doc.createElement("gameRequest");
        doc.appendChild(requestElt);

        Node requestIdElt = doc.createElement("requestId");
        requestIdElt.setTextContent(id);
        requestElt.appendChild(requestIdElt);

        Node challengerElt = doc.createElement("challengerId");
        challengerElt.setTextContent(userId);
        requestElt.appendChild(challengerElt);

        Node receiverElt = doc.createElement("receiverId");
        receiverElt.setTextContent(String.valueOf(receiverId));
        requestElt.appendChild(receiverElt);

        Node puzzleElt = doc.createElement("puzzleId");
        puzzleElt.setTextContent(String.valueOf(puzzleId));
        requestElt.appendChild(puzzleElt);

        Node puzzleNameElt = doc.createElement("puzzleName");
        puzzleNameElt.setTextContent(name);
        requestElt.appendChild(puzzleNameElt);

        Node dateElt = doc.createElement("requestDate");
        dateElt.setTextContent(String.valueOf(new Date(new java.util.Date().getTime())));
        requestElt.appendChild(dateElt);

        Node typeElt = doc.createElement("type");
        typeElt.setTextContent(type);
        requestElt.appendChild(typeElt);

        Node challengeScoreElt = doc.createElement("challengeScore");
        challengeScoreElt.setTextContent(String.valueOf(score));
        requestElt.appendChild(challengeScoreElt);

        Node receiverScoreElt = doc.createElement("receiverScore");
        receiverScoreElt.setTextContent("0");
        requestElt.appendChild(receiverScoreElt);

        Node winnerElt = doc.createElement("winner");
        winnerElt.setTextContent("");
        requestElt.appendChild(winnerElt);
    }

    public static void generateQuestionSetNodes(Document doc, int puzzleId, ArrayList<ContentValues> questionSet) {
        Node questionsSetElt = doc.createElement("questionsets");
        doc.appendChild(questionsSetElt);

        Node puzzleIdElt = doc.createElement("puzzleId");
        puzzleIdElt.setTextContent(String.valueOf(puzzleId));
        questionsSetElt.appendChild(puzzleIdElt);

        for (ContentValues cv : questionSet) {
            Node questionSetElt = doc.createElement("questionset");
            questionsSetElt.appendChild(questionSetElt);

            Node idElt = doc.createElement("id");
            idElt.setTextContent(cv.getAsString(General.ID));
            questionsSetElt.appendChild(idElt);

            Node answerElt = doc.createElement("answer");
            answerElt.setTextContent(cv.getAsString(General.XML_TAG_ANSWER));
            questionSetElt.appendChild(answerElt);

            Node questionElt = doc.createElement("question");
            questionElt.setTextContent(cv.getAsString(General.XML_TAG_QUESTION));
            questionSetElt.appendChild(questionElt);

            Node inputMethodElt = doc.createElement("inputmethod");
            inputMethodElt.setTextContent(cv.getAsString(General.XML_TAG_QUESTION));
            questionSetElt.appendChild(inputMethodElt);

        }
    }

    public static void generatePuzzleAndQuestionSetNode(Document doc, ContentValues puzzle, ArrayList<String> coAuthors,
                                                        String nickname, ArrayList<ContentValues> questionSet) {
        Node puzzleElt = doc.createElement("puzzle");
        doc.appendChild(puzzleElt);

        Node idElt = doc.createElement("id");
        idElt.setTextContent(puzzle.getAsString(General.ID));
        puzzleElt.appendChild(idElt);

        Node subjectElt = doc.createElement("name");
        subjectElt.setTextContent(puzzle.getAsString(General.PUZZLE_NAME));
        puzzleElt.appendChild(subjectElt);

        Node contentElt = doc.createElement("category");
        contentElt.setTextContent(puzzle.getAsString(General.PUZZLE_CATEGORY));
        puzzleElt.appendChild(contentElt);

        Node authorElt = doc.createElement("author");
        authorElt.setTextContent(nickname);
        puzzleElt.appendChild(authorElt);

        if (coAuthors != null && coAuthors.size() > 0) {
            Node coauthorsElt = doc.createElement(General.XML_TAG_COAUTHORS);
            puzzleElt.appendChild(coauthorsElt);

            for (String author : coAuthors) {
                Node coauthorElt = doc.createElement(General.XML_TAG_COAUTHOR);
                coauthorElt.setTextContent(author);
                coauthorsElt.appendChild(coauthorElt);
            }
        }
        if (questionSet != null && questionSet.size() > 0) {
            for (ContentValues cv : questionSet) {
                Node questionSetElt = doc.createElement("questionset");
                puzzleElt.appendChild(questionSetElt);

                Node setIdElt = doc.createElement("setId");
                idElt.setTextContent(cv.getAsString(General.XML_TAG_SET_ID));
                questionSetElt.appendChild(setIdElt);

                Node answerElt = doc.createElement("answer");
                answerElt.setTextContent(cv.getAsString(General.XML_TAG_ANSWER));
                questionSetElt.appendChild(answerElt);

                Node questionElt = doc.createElement("question");
                questionElt.setTextContent(cv.getAsString(General.XML_TAG_QUESTION));
                questionSetElt.appendChild(questionElt);

                Node inputMethodElt = doc.createElement("inputmethod");
                inputMethodElt.setTextContent(cv.getAsString(General.XML_TAG_INPUTMETHOD));
                questionSetElt.appendChild(inputMethodElt);

            }
        }
    }
}
