package com.master.playit;

import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
import com.master.playit.helper.General;
import com.master.playit.helper.XmlGeneratorHelper;
import org.restlet.data.MediaType;
import org.restlet.ext.xml.DomRepresentation;
import org.restlet.representation.Representation;
import org.restlet.resource.ClientResource;
import org.w3c.dom.Document;
import roboguice.activity.RoboActivity;
import roboguice.inject.InjectView;

import java.io.IOException;

public class RegisterActivity extends RoboActivity {
    @InjectView(R.id.EditText_LoginNickname)
    EditText nicknameText;
    @InjectView(R.id.Button_Login)
    Button loginButton;

    private SharedPreferences settings;
    private final int REGISTER_DIALOG = 1;
    private SaveNewUser saveUser;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.register);
        settings = getSharedPreferences(General.GAME_PREFERENCES, MODE_PRIVATE);

//        Debug purposes, removes the log in and sets current user to "test"
        SharedPreferences.Editor editor = settings.edit();
        editor.putString(General.GAME_PREFERENCES_NICKNAME, "test");
        editor.putInt(General.GAME_PREFERENCES_PLAYER_ID, 1);
        editor.commit();
        startActivity(new Intent(this, MainActivity.class));

//        Uncomment and comment out the above to make log in function work
//        if (settings.getInt(General.GAME_PREFERENCES_PLAYER_ID, -1) == -1) {
//            nicknameText.setText(settings.getString(General.GAME_PREFERENCES_NICKNAME, ""));
//            setLoginButtonListener();
//        } else {
//            startActivity(new Intent(this, MainActivity.class));
//        }


    }

    private void setLoginButtonListener() {
        loginButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                String nickname = nicknameText.getText().toString();
                if (nickname.length() >= 5) {
                    SharedPreferences.Editor editor = settings.edit();
                    editor.putString(General.GAME_PREFERENCES_NICKNAME, nickname);
                    editor.commit();
                    saveUser = new SaveNewUser();
                    saveUser.execute(nickname);
                } else if (nickname.length() < 5) {
                    Toast.makeText(RegisterActivity.this, "Nickname must be 5 or more characters long",
                            Toast.LENGTH_SHORT).show();
                }
            }
        });
    }

    @Override
    protected Dialog onCreateDialog(int id) {
        if (id == REGISTER_DIALOG) {
            ProgressDialog dialog = new ProgressDialog(RegisterActivity.this, ProgressDialog.STYLE_SPINNER);
            dialog.setIndeterminate(true);
            dialog.setMessage(getResources().getString(R.string.logging_in));
            dialog.setCancelable(false);
            return dialog;
        }
        return null;
    }

    /**
     * Save new user and get the userId from the server
     */
    private class SaveNewUser extends AsyncTask<String, String, String> {
        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            showDialog(REGISTER_DIALOG);
        }

        @Override
        protected String doInBackground(String... strings) {
            String nickname = strings[0];

            ClientResource serverClient = new ClientResource(General.SERVER_USER);
            try {
                DomRepresentation rep = new DomRepresentation(MediaType.APPLICATION_XML);
                Document doc = rep.getDocument();

                XmlGeneratorHelper.generateUserNode(doc, nickname, settings.getInt(General.GAME_PREFERENCES_PLAYER_ID, 0));
                Representation userRepresentation = serverClient.put(rep);

                String userId = userRepresentation.getText();
                if (!userId.equals("0")) {
                    SharedPreferences.Editor editor = settings.edit();
                    editor.putInt(General.GAME_PREFERENCES_PLAYER_ID, Integer.parseInt(userId));
                    editor.commit();
                    return "true";
                }
            } catch (IOException e) {
                Log.e(General.DEBUG_TAG, "IOException on generating and requesting user, userId not saved");
                e.printStackTrace();
            }
            Toast.makeText(RegisterActivity.this, "New user was not registered, please try again",
                    Toast.LENGTH_SHORT).show();
            return null;
        }

        @Override
        protected void onPostExecute(String s) {
            super.onPostExecute(s);
            dismissDialog(REGISTER_DIALOG);
            startActivity(new Intent().setClass(getBaseContext(), MainActivity.class));
        }
    }
}
